@@ -1,13 +1,12 @@
 package CPAN::Packager::DownloaderFactory;
 use strict;
 use warnings;
-use UNIVERSAL::require;
 
 sub create {
     my ( $class, $downloader, $config ) = @_;
     my $builder_class = join '::',
         ( 'CPAN', 'Packager', 'Downloader', $downloader );
-    $builder_class->require or die "Can't load module $@";
+    eval "require $builder_class;" or die "Can't load module $@"; ## no critic
     $builder_class->new;
 }
 
